from distutils.core import setup
setup(
    name="jungle1",
    version="1.0.0",
    py_modules=["jungle1"],
    author="lgno",
    author_email="giserwangziheng@163.com",
    description="A simple printer of jungle1 lists"

)